[qca-nss-drv] Fix typo in common response message

Change-Id: I22a275e1f7eaa33cadfb057eb0bf9f74d2cf6899
Signed-off-by: Suruchi Agarwal <suruchia@codeaurora.org>
diff --git a/nss_n2h.c b/nss_n2h.c
index 052282a..d962fa1 100644
--- a/nss_n2h.c
+++ b/nss_n2h.c
@@ -107,10 +107,10 @@
 	 * Update the callback and app_data for NOTIFY messages, n2h sends all notify messages
 	 * to the same callback/app_data.
 	 */
-	if (nnm->cm.response == NSS_CMM_RESPONSE_NOTIFY) {
+	if (nnm->cm.response == NSS_CMN_RESPONSE_NOTIFY) {
 		/*
 		 * Place holder for the user to create right call
 		 * back and app data when response is NSS_CMM_RESPONSE_NOTIFY
 		 */
 		ncm->cb = (nss_ptr_t)nss_n2h_rd[nss_ctx->id].n2h_callback;
 		ncm->app_data = (nss_ptr_t)nss_n2h_rd[nss_ctx->id].app_data;
@@ -107,10 +107,10 @@
 		/*
 		 * Place holder for the user to create right call
-		 * back and app data when response is NSS_CMM_RESPONSE_NOTIFY
+		 * back and app data when response is NSS_CMN_RESPONSE_NOTIFY
 		 */
 		ncm->cb = (nss_ptr_t)nss_n2h_rd[nss_ctx->id].n2h_callback;